Schema Documentation¶
This page contains the auto-generated technical documentation for all sections, quantities, and subsections defined in the nomad-catalysis plugin.
For contextual descriptions and usage guidance, see:
- Catalyst Sample — catalyst material metadata
- Catalytic Reaction — reaction measurement data
- Collection Parser — batch entry creation
You can also explore the schemas interactively in the NOMAD Metainfo Browser.
RawFileData¶
description: A section for storing the raw data file that was parsedby the catalytic reaction or catalyst sample parser.
inherits from: nomad.datamodel.data.EntryData
properties:
| name | type | |
|---|---|---|
| measurement | nomad.datamodel.metainfo.basesections.v1.Measurement |
normalization without further documentation
CatalysisCollectionParserEntry¶
description: A section for storing the references to individual entries generated by the catalysis parser.
inherits from: nomad.datamodel.data.EntryData
properties:
| name | type | |
|---|---|---|
| data_file | str |
The name of the data file that was parsed. |
| samples | nomad.datamodel.metainfo.basesections.v1.CompositeSystemReference |
sub-section, repeats |
| measurements | nomad.datamodel.metainfo.basesections.v1.SectionReference |
A subsection with references to the measurement entries that weregenerated from the data file.sub-section, repeats |
normalization without further documentation
Preparation¶
description: A section for general information about the preparation of a catalyst sample.
inherits from: nomad.datamodel.data.ArchiveSection
properties:
| name | type | |
|---|---|---|
| preparation_method | str |
Classification of the dominant preparation step in the catalyst synthesis procedure. |
| preparator | str |
The person or persons preparing the sample in the lab. |
| preparing_institution | str |
institution at which the sample was prepared |
SurfaceArea¶
description: A section for specifying the specific surface area or dispersion of a catalyst sample and the method that was used determining this quantity.
inherits from: nomad.datamodel.data.ArchiveSection
properties:
| name | type | |
|---|---|---|
| surface_area | float64 |
unit=meter ** 2 / gram |
| method_surface_area_determination | str |
A description of the method used to measure the surface area of the sample. |
| dispersion | float64 |
The fraction of total atoms which are surface atoms of a particle as a measure for the accessibility of the atoms. |
CatalystSample¶
description: An entry schema for specifying general information about a catalyst sample.
inherits from: nomad.datamodel.metainfo.basesections.v1.CompositeSystem, nomad.datamodel.data.EntryData
links: https://w3id.org/nfdi4cat/voc4cat_0007003
properties:
| name | type | |
|---|---|---|
| storing_institution | str |
The institution at which the sample is stored. |
| catalyst_type | str |
A classification of the catalyst type.shape=['*'] |
| support | str |
The material that the active phase is supported on. |
| formula_descriptive | str |
A descriptive formula of the catalyst sample. |
| form | str |
classification of physical form of catalyst |
| preparation_details | Preparation |
sub-section |
| surface | SurfaceArea |
sub-section |
normalization without further documentation
ReactorFilling¶
description: A class containing information about the catalyst and filling in the reactor.
inherits from: nomad.datamodel.data.ArchiveSection
properties:
| name | type | |
|---|---|---|
| catalyst_name | str |
|
| sample_section_reference | nomad.datamodel.metainfo.basesections.v1.CompositeSystemReference |
A reference to the sample reference used in the measurement. |
| catalyst_mass | float64 |
The mass of the catalyst placed in the reactor.unit=kilogram |
| catalyst_density | float64 |
unit=kilogram / meter ** 3 |
| catalyst_volume | float64 |
unit=meter ** 3 |
| catalyst_sievefraction_upper_limit | float64 |
unit=meter |
| catalyst_sievefraction_lower_limit | float64 |
unit=meter |
| particle_size | float64 |
unit=meter |
| diluent | str |
A component that is mixed with the catalyst to dilute and prevent transport limitations and hot spot formation. |
| diluent_mass | float64 |
unit=kilogram |
| diluent_sievefraction_upper_limit | float64 |
unit=meter |
| diluent_sievefraction_lower_limit | float64 |
unit=meter |
normalization:
The normalizer for the ReactorFilling class. It links the catalyst if a
sample was referenced in the sample subsection of the entry and
fills the catalyst name from the sample subsection.
If catalyst mass and density are given, the catalyst volume is calculated.
Args: archive (EntryArchive): The archive containing the section that is being normalized. logger ('BoundLogger'): A structlog logger.
ReactorSetup¶
description: Specification about the type of reactor used in the measurement.
inherits from: nomad.datamodel.metainfo.basesections.v1.InstrumentReference
links: https://w3id.org/nfdi4cat/voc4cat_0000152
properties:
| name | type | |
|---|---|---|
| name | str |
A short descriptive name for the role of this reference. |
| reactor_type | str |
Type of reactor model used in the measurement. |
| bed_length | float64 |
unit=meter |
| reactor_cross_section_area | float64 |
unit=meter ** 2 |
| reactor_diameter | float64 |
unit=meter |
| reactor_volume | float64 |
unit=meter ** 3 |
normalization:
Will attempt to fill the reference from the lab_id or vice versa.
Reagent¶
description: A chemical substance present in the initial reaction mixture.
inherits from: nomad.datamodel.data.ArchiveSection
properties:
| name | type | |
|---|---|---|
| name | str |
reagent name |
| fraction_in | float64 |
Volumetric fraction of reactant in feed. The value must be between 0 and 1.shape=['*'] |
| flow_rate | float64 |
Flow rate of reactant in feed.shape=['*'], unit=meter ** 3 / second |
| partial_pressure_in | float64 |
Partial pressure of reactant in initial reaction mixture.shape=['*'], unit=pascal |
| pure_component | nomad.datamodel.metainfo.basesections.v1.PubChemPureSubstanceSection |
sub-section |
normalization:
The normalizer will run for the subsection PureSubstanceComponent class.
A few exceptions are set here for reagents with ambiguous names or missing
entries in the PubChem database. A time.sleep(1) is set to prevent blocked IP
due to too many requests to the PubChem database.
If none is set, the normalizer will set the name of the component to be the
molecular formula of the substance.
Args: archive (EntryArchive): The archive containing the section that is being normalized. logger ('BoundLogger'): A structlog logger.
ReactantData¶
description: A reagent that has a conversion in a reaction that is not null
inherits from: Reagent
properties:
| name | type | |
|---|---|---|
| fraction_out | float64 |
Volumetric fraction of reactant in outlet. The value must be between 0 and 1shape=['*'] |
| conversion | float64 |
The conversion of the reactant in the reaction mixture. The value is in %shape=['*'] |
| conversion_type | str |
Specifies the way the conversion was calculated in this reaction. The value is either product-based, reactant-based or unknown |
| conversion_product_based | float64 |
shape=['*'] |
| conversion_reactant_based | float64 |
shape=['*'] |
normalization:
The normalizer will run for the subsection PureSubstanceComponent class.
A few exceptions are set here for reagents with ambiguous names or missing
entries in the PubChem database. A time.sleep(1) is set to prevent blocked IP
due to too many requests to the PubChem database.
If none is set, the normalizer will set the name of the component to be the
molecular formula of the substance.
Args: archive (EntryArchive): The archive containing the section that is being normalized. logger ('BoundLogger'): A structlog logger.
RatesData¶
inherits from: nomad.datamodel.data.ArchiveSection
properties:
| name | type | |
|---|---|---|
| name | str |
|
| reaction_rate | float64 |
The reaction rate for mmol of product (or reactant) formed (depleted) per catalyst (g) per time (hour).shape=['*'], unit=millimole / gram / hour |
| specific_mass_rate | float64 |
The specific reaction rate normalized by active (metal) catalyst mass, instead of mass of total catalyst.shape=['*'], unit=millimole / gram / hour |
| specific_surface_area_rate | float64 |
The specific reaction rate normalized by active (metal) surface area of catalyst, instead of mass of total catalyst.shape=['*'], unit=millimole / hour / meter ** 2 |
| rate | float64 |
The amount of reactant converted (in g), per total catalyst (g) per time (hour).shape=['*'], unit=1 / hour |
| turnover_frequency | float64 |
The turn oder frequency, calculated from mol of reactant or product, per number of sites, over time.shape=['*'], unit=1 / hour |
| pure_component | nomad.datamodel.metainfo.basesections.v1.PubChemPureSubstanceSection |
sub-section |
normalization without further documentation
ProductData¶
description: A chemical substance formed in the reaction mixture during a reaction.
inherits from: Reagent
properties:
| name | type | |
|---|---|---|
| fraction_out | float64 |
Volumetric fraction of reactant in outlet. The value must be between 0 and 1shape=['*'] |
| selectivity | float64 |
The selectivity of the product in the reaction mixture. The value is in %.shape=['*'] |
| product_yield | float64 |
The yield of the product in the reaction mixture, calculated as conversion * selectivity.shape=['*'] |
| space_time_yield | float64 |
The amount of product formed (in g), per total catalyst (g) per time (s).shape=['*'], unit=1 / second |
normalization:
The normalizer for the adjusted PureSubstanceComponent class. If none is set,
the normalizer will set the name of the component to be the molecular formula of
the substance.
Args: archive (EntryArchive): The archive containing the section that is being normalized. logger ('BoundLogger'): A structlog logger.
ReactionConditionsData¶
description: A class containing reaction conditions for a generic reaction.
inherits from: nomad.datamodel.metainfo.plot.PlotSection
links: https://w3id.org/nfdi4cat/voc4cat_0007039
properties:
| name | type | |
|---|---|---|
| set_temperature | float64 |
shape=['*'], unit=kelvin |
| set_pressure | float64 |
shape=['*'], unit=pascal |
| set_total_flow_rate | float64 |
shape=['*'], unit=meter ** 3 / second |
| weight_hourly_space_velocity | float64 |
A measure for how often the atmosphere in the reactor is replaced over the catalyst. Calculated as the total flow rate divided by the catalyst mass.shape=['*'], unit=meter ** 3 / kilogram / second |
| contact_time | float64 |
The time the reactants are in contact with the catalyst. Also the reciprocal of the weight hourly space velocity. Calculated as the catalyst mass divided by the total flow rate.shape=['*'], unit=kilogram * second / meter ** 3 |
| gas_hourly_space_velocity | float64 |
Similar to WHSV, the volumetric flow rate of the gas divided by the control volume. In heterogeneous catalysis the volume of the undiluted catalyst bed is conventionally used as the control volume.shape=['*'], unit=1 / second |
| runs | float64 |
shape=['*'] |
| sampling_frequency | float64 |
The number of measurement points per time.unit=hertz |
| time_on_stream | float64 |
The running time of the reaction since gas flow and measurement started.shape=['*'], unit=second |
| reagents | Reagent |
sub-section, repeats |
normalization without further documentation
ReagentBatch¶
description: A reagent in a batch reaction.
inherits from: Reagent
properties:
| name | type | |
|---|---|---|
| amount | float64 |
The amount n of the reagent in the reaction mixture in mole.unit=mole |
| mass | float64 |
unit=kilogram |
| volume | float64 |
unit=meter ** 3 |
normalization:
The normalizer will run for the subsection PureSubstanceComponent class.
A few exceptions are set here for reagents with ambiguous names or missing
entries in the PubChem database. A time.sleep(1) is set to prevent blocked IP
due to too many requests to the PubChem database.
If none is set, the normalizer will set the name of the component to be the
molecular formula of the substance.
Args: archive (EntryArchive): The archive containing the section that is being normalized. logger ('BoundLogger'): A structlog logger.
ReactionConditionsBatchData¶
description: A class containing reaction conditions for a batch reaction.
inherits from: ReactionConditionsData
properties:
| name | type | |
|---|---|---|
| stirring_rate | float64 |
The rate at which the reaction mixture is stirred. The value is in 1/sunit=1 / second |
| reaction_time | float64 |
shape=['*'], unit=second |
| reagents | ReagentBatch |
sub-section, repeats |
normalization without further documentation
CatalyticReactionCore¶
inherits from: nomad.datamodel.metainfo.basesections.v1.Measurement
properties:
| name | type | |
|---|---|---|
| reaction_type | str |
A highlevel classification of the studied reaction.shape=['*'] |
| reaction_name | str |
The name of the studied reaction. |
| experiment_handbook | str |
In case the experiment was performed according to a handbook. |
| location | str |
The institution at which the measurement was performed. |
| experimenter | str |
The person that performed or started the measurement. |
normalization:
- Updates the
archive.workflow2.inputslist with links to the input samples. - Updates the
archive.workflow2.outputslist with links to the measurement results.
CatalyticReactionData¶
inherits from: nomad.datamodel.metainfo.plot.PlotSection, nomad.datamodel.metainfo.basesections.v1.MeasurementResult
properties:
| name | type | |
|---|---|---|
| temperature | float64 |
shape=['*'], unit=kelvin |
| pressure | float64 |
shape=['*'], unit=pascal |
| total_flow_rate | float64 |
shape=['*'], unit=meter ** 3 / second |
| runs | float64 |
shape=['*'] |
| time_on_stream | float64 |
shape=['*'], unit=second |
| c_balance | float64 |
Carbon balance is the ratio of detected carbon in the products to the carbon in the feed. It is a measure of the quality of the gas analysis or could indicate the amount of coke formationshape=['*'] |
| reactants_conversions | ReactantData |
sub-section, repeats |
| rates | RatesData |
sub-section, repeats |
| products | ProductData |
sub-section, repeats |
normalization without further documentation
CatalyticReaction¶
description: An activity entry containing information about a catalytic reaction.
inherits from: CatalyticReactionCore, nomad.datamodel.metainfo.plot.PlotSection, nomad.datamodel.data.EntryData
links: https://w3id.org/nfdi4cat/voc4cat_0005007
properties:
| name | type | |
|---|---|---|
| data_file | str |
A file that contains reaction conditions and results of a catalytic measurement. Supported file formats are .csv or .xlsx with columns matching the clean data standards and hf5 files generated by the automated haber reactor at the FHI. More details can be found in the documentation of the nomad-catalysis-plugin. |
| instruments | ReactorSetup |
A list of all the instruments and their role in this process.sub-section, repeats |
| reactor_filling | ReactorFilling |
sub-section |
| pretreatment | ReactionConditionsData |
sub-section |
| reaction_conditions | ReactionConditionsData |
sub-section |
| results | CatalyticReactionData |
The result of the measurement.sub-section, repeats |
normalization without further documentation